package com.mysql.jdbc;

import com.mysql.jdbc.profiler.ProfileEventSink;
import com.mysql.jdbc.profiler.ProfilerEvent;
import java.sql.SQLException;

/* loaded from: com_mysql_jdbc.jar:com/mysql/jdbc/RowDataDynamic.class */
public class RowDataDynamic implements RowData {
    private int columnCount;
    private Field[] metadata;
    private MysqlIO io;
    private boolean isBinaryEncoded;
    private ResultSetRow nextRow;
    private ResultSetImpl owner;
    private boolean useBufferRowExplicit;
    private int index = -1;
    private boolean isAfterEnd = false;
    private boolean isAtEnd = false;
    private boolean streamerClosed = false;
    private boolean wasEmpty = false;

    /* JADX INFO: Access modifiers changed from: package-private */
    /* loaded from: com_mysql_jdbc.jar:com/mysql/jdbc/RowDataDynamic$OperationNotSupportedException.class */
    public class OperationNotSupportedException extends SQLException {
        private final RowDataDynamic this$0;

        OperationNotSupportedException(RowDataDynamic this$0) {
            super(Messages.getString("RowDataDynamic.10"), SQLError.SQL_STATE_ILLEGAL_ARGUMENT);
            this.this$0 = this$0;
        }
    }

    public RowDataDynamic(MysqlIO io, int colCount, Field[] fields, boolean isBinaryEncoded) throws SQLException {
        this.isBinaryEncoded = false;
        this.io = io;
        this.columnCount = colCount;
        this.isBinaryEncoded = isBinaryEncoded;
        this.metadata = fields;
        this.useBufferRowExplicit = MysqlIO.useBufferRowExplicit(this.metadata);
    }

    @Override // com.mysql.jdbc.RowData
    public void addRow(ResultSetRow row) throws SQLException {
        notSupported();
    }

    @Override // com.mysql.jdbc.RowData
    public void afterLast() throws SQLException {
        notSupported();
    }

    @Override // com.mysql.jdbc.RowData
    public void beforeFirst() throws SQLException {
        notSupported();
    }

    @Override // com.mysql.jdbc.RowData
    public void beforeLast() throws SQLException {
        notSupported();
    }

    /* JADX WARN: Finally extract failed */
    @Override // com.mysql.jdbc.RowData
    public void close() throws SQLException {
        Object mutex = this;
        ConnectionImpl conn = null;
        if (this.owner != null) {
            conn = this.owner.connection;
            if (conn != null) {
                mutex = conn.getMutex();
            }
        }
        boolean hadMore = false;
        int howMuchMore = 0;
        synchronized (mutex) {
            while (next() != null) {
                hadMore = true;
                howMuchMore++;
                if (howMuchMore % 100 == 0) {
                    Thread.yield();
                }
            }
            if (conn != null) {
                if (!conn.getClobberStreamingResults() && conn.getNetTimeoutForStreamingResults() > 0) {
                    String oldValue = conn.getServerVariable("net_write_timeout");
                    if (oldValue == null || oldValue.length() == 0) {
                        oldValue = "60";
                    }
                    this.io.clearInputStream();
                    java.sql.Statement stmt = null;
                    try {
                        stmt = conn.createStatement();
                        stmt.executeUpdate(new StringBuffer().append("SET net_write_timeout=").append(oldValue).toString());
                        if (stmt != null) {
                            stmt.close();
                        }
                    } catch (Throwable th) {
                        if (stmt != null) {
                            stmt.close();
                        }
                        throw th;
                    }
                }
                if (conn.getUseUsageAdvisor() && hadMore) {
                    ProfileEventSink eventSink = ProfileEventSink.getInstance(conn);
                    eventSink.consumeEvent(new ProfilerEvent((byte) 0, "", this.owner.owningStatement == null ? "N/A" : this.owner.owningStatement.currentCatalog, this.owner.connectionId, this.owner.owningStatement == null ? -1 : this.owner.owningStatement.getId(), -1, System.currentTimeMillis(), 0L, Constants.MILLIS_I18N, (String) null, (Throwable) null, new StringBuffer().append(Messages.getString("RowDataDynamic.2")).append(howMuchMore).append(Messages.getString("RowDataDynamic.3")).append(Messages.getString("RowDataDynamic.4")).append(Messages.getString("RowDataDynamic.5")).append(Messages.getString("RowDataDynamic.6")).append(this.owner.pointOfOrigin).toString()));
                }
            }
        }
        this.metadata = null;
        this.owner = null;
    }

    @Override // com.mysql.jdbc.RowData
    public ResultSetRow getAt(int ind) throws SQLException {
        notSupported();
        return null;
    }

    @Override // com.mysql.jdbc.RowData
    public int getCurrentRowNumber() throws SQLException {
        notSupported();
        return -1;
    }

    @Override // com.mysql.jdbc.RowData
    public ResultSetInternalMethods getOwner() {
        return this.owner;
    }

    @Override // com.mysql.jdbc.RowData
    public boolean hasNext() throws SQLException {
        boolean hasNext = this.nextRow != null;
        if (!hasNext && !this.streamerClosed) {
            this.io.closeStreamer(this);
            this.streamerClosed = true;
        }
        return hasNext;
    }

    @Override // com.mysql.jdbc.RowData
    public boolean isAfterLast() throws SQLException {
        return this.isAfterEnd;
    }

    @Override // com.mysql.jdbc.RowData
    public boolean isBeforeFirst() throws SQLException {
        return this.index < 0;
    }

    @Override // com.mysql.jdbc.RowData
    public boolean isDynamic() {
        return true;
    }

    @Override // com.mysql.jdbc.RowData
    public boolean isEmpty() throws SQLException {
        notSupported();
        return false;
    }

    @Override // com.mysql.jdbc.RowData
    public boolean isFirst() throws SQLException {
        notSupported();
        return false;
    }

    @Override // com.mysql.jdbc.RowData
    public boolean isLast() throws SQLException {
        notSupported();
        return false;
    }

    @Override // com.mysql.jdbc.RowData
    public void moveRowRelative(int rows) throws SQLException {
        notSupported();
    }

    @Override // com.mysql.jdbc.RowData
    public ResultSetRow next() throws SQLException {
        nextRecord();
        if (this.nextRow == null && !this.streamerClosed) {
            this.io.closeStreamer(this);
            this.streamerClosed = true;
        }
        if (this.nextRow != null && this.index != Integer.MAX_VALUE) {
            this.index++;
        }
        return this.nextRow;
    }

    /* JADX WARN: Multi-variable type inference failed */
    private void nextRecord() throws SQLException {
        try {
            if (!this.isAtEnd) {
                this.nextRow = this.io.nextRow(this.metadata, this.columnCount, this.isBinaryEncoded, MysqlErrorNumbers.ER_DB_CREATE_EXISTS, true, this.useBufferRowExplicit, true, null);
                if (this.nextRow == null) {
                    this.isAtEnd = true;
                    if (this.index == -1) {
                        this.wasEmpty = true;
                    }
                }
            } else {
                this.isAfterEnd = true;
            }
        } catch (SQLException e) {
            if (e instanceof StreamingNotifiable) {
                ((StreamingNotifiable) e).setWasStreamingResults();
            }
            throw e;
        } catch (Exception ex) {
            String exceptionType = ex.getClass().getName();
            String exceptionMessage = ex.getMessage();
            throw new SQLException(new StringBuffer().append(Messages.getString("RowDataDynamic.8")).append(exceptionType).append(Messages.getString("RowDataDynamic.9")).append(new StringBuffer().append(new StringBuffer().append(exceptionMessage).append(Messages.getString("RowDataDynamic.7")).toString()).append(Util.stackTraceToString(ex)).toString()).toString(), SQLError.SQL_STATE_GENERAL_ERROR);
        }
    }

    private void notSupported() throws SQLException {
        throw new OperationNotSupportedException(this);
    }

    @Override // com.mysql.jdbc.RowData
    public void removeRow(int ind) throws SQLException {
        notSupported();
    }

    @Override // com.mysql.jdbc.RowData
    public void setCurrentRow(int rowNumber) throws SQLException {
        notSupported();
    }

    @Override // com.mysql.jdbc.RowData
    public void setOwner(ResultSetImpl rs) {
        this.owner = rs;
    }

    @Override // com.mysql.jdbc.RowData
    public int size() {
        return -1;
    }

    @Override // com.mysql.jdbc.RowData
    public boolean wasEmpty() {
        return this.wasEmpty;
    }

    @Override // com.mysql.jdbc.RowData
    public void setMetadata(Field[] metadata) {
        this.metadata = metadata;
    }
}
